Example programs
==============================================

This is a collection of example programs based on fwdpy11.

These scripts are maintained as a separate GitHub repository so that they
can be experimented with.  However, they are also included with the fwdpy11
repository.

Dependencies
-------------------------------------

Please note that these examples require more dependencies than fwdpy11 itself does.
Futher, these requirements are **not** part of the fwdpy11 dependenecy list (because I don't
want your `pip` to install a bunch of stuff not required for fwdpy11 itself).

These dependencies are, at minimum:

* seaborn >= 0.9.0
* sqlite3
* R, with Rscript
* The dplyr package for R


